﻿package 
{
	import com.greensock.easing.*;
	import com.greensock.OverwriteManager;
	import com.greensock.plugins.GlowFilterPlugin;
	import com.greensock.plugins.TintPlugin;
	import com.greensock.plugins.TweenPlugin;
	import com.greensock.TweenLite;
	import flash.display.MovieClip;
	import flash.display.SimpleButton;
	import flash.events.MouseEvent;
	import flash.utils.getTimer;
	import flash.net.URLRequest;
    import flash.net.navigateToURL;
	
	/**
	 * Base document class for the "More than IT" Experis - ManPower banner.
	 * @author Derrick Williams
	 */
	public class  MoreThanIT_Cable_Base extends MovieClip
	{
		// --------------------------------------------------------------------
		//	Constants
		// --------------------------------------------------------------------
		
		public static const RECEPTOR_START_ALPHA:Number = 0.6;
		public static const RECEPTOR_HIGHLIGHT_ALPHA:Number = 1.0;
		public static const WIRE_EASE:Function = Expo.easeOut;
		
		
		// --------------------------------------------------------------------
		//	Constructor
		// --------------------------------------------------------------------
		
		public function MoreThanIT_Cable_Base ()
		{
			init();
			animate();
		}
		
		// --------------------------------------------------------------------
		//	Local Variables
		// --------------------------------------------------------------------
		
		protected var numLines:int = 7;
		
		// --------------------------------------------------------------------
		//	Stage Elements
		// --------------------------------------------------------------------
		
		public var clickTagBtn:SimpleButton;
		public var headline:MovieClip;
		public var experisLogo:MovieClip;
		public var cableGuy:MovieClip;
		public var ctaBtn:MovieClip;
		public var loopReceptor:MovieClip;
		public var line1:MovieClip;
		public var line2:MovieClip;
		public var line3:MovieClip;
		public var line4:MovieClip;
		public var line5:MovieClip;
		public var line6:MovieClip;
		public var line7:MovieClip;
	 
		// --------------------------------------------------------------------
		//	Methods
		// --------------------------------------------------------------------
		
		protected function init():void
		{
			OverwriteManager.init(OverwriteManager.AUTO);
			TweenPlugin.activate([GlowFilterPlugin, TintPlugin]);
			
			// add clickTag event handlers
			clickTagBtn.addEventListener(MouseEvent.CLICK, clickTagBtn_clickHandler);
			clickTagBtn.addEventListener(MouseEvent.ROLL_OVER, clickTagBtn_rollOverHandler );
			clickTagBtn.addEventListener(MouseEvent.ROLL_OUT, clickTagBtn_rollOutHandler );
		
			// change the alpha of the wires
			if (loopReceptor) 
				loopReceptor.alpha = RECEPTOR_START_ALPHA;
			
			for (var i:int = 1; i < numLines+1; i++) {
				var lineWire:MovieClip = this["line" + i].wire;
				
				if(lineWire)
					lineWire.alpha = RECEPTOR_START_ALPHA;
			}
		}
		
		protected function animate():void
		{
			animateFrame1(0.2);
			animateFrame2(4.5);
			animateFrame3(8.0);
		}
		
		protected function animateFrame1(delay:Number=0):void
		{
			TweenLite.from(cableGuy, 0.8, {x: 600, delay: delay} );
			TweenLite.from(experisLogo, 0.4, {alpha: 0, delay: delay + 0.25} );
			TweenLite.from(headline, 0.5, { alpha: 0, x: "-40", delay: delay + 0.5, ease: Linear.easeOut } );
			
			TweenLite.delayedCall(delay + 0.5, showLoopReceptor);
			delay += 0.5;
			
			TweenLite.from(line1, 0.5, {alpha: 0, x: 0, delay: delay + 1.5, ease: WIRE_EASE} );
			TweenLite.from(line2, 0.5, {alpha: 0, x: 0, delay: delay + 1.75, ease: WIRE_EASE} );
		}
		
		protected function animateFrame2(delay:Number=0):void
		{
			// hide frame 1
			TweenLite.to(line1, 0.5, {alpha: 0, delay: delay + 0.5} );
			TweenLite.to(line2, 0.5, {alpha: 0, delay: delay + 0.75} );
			
			// show frame 2
			TweenLite.from(line3, 0.5, {alpha: 0, x: 0, delay: delay + 1.0, ease: WIRE_EASE} );
			TweenLite.from(line4, 0.5, {alpha: 0, x: 0, delay: delay + 1.25, ease: WIRE_EASE} );
		}
		
		protected function animateFrame3(delay:Number=0):void
		{
			// hide frame 2
			TweenLite.to(line3, 0.5, {alpha: 0, delay: delay + 0.5} );
			TweenLite.to(line4, 0.5, {alpha: 0, delay: delay + 0.75, onComplete: traceTimestamp} );
			
			// show frame 3
			TweenLite.delayedCall(delay + 1.5, showLoopReceptor);
			TweenLite.from(line5, 0.5, {alpha: 0, x: 0, delay: delay + 1.0, ease: WIRE_EASE } );
			TweenLite.from(line6, 0.5, {alpha: 0, x: 0, delay: delay + 1.25, ease: WIRE_EASE} );
			TweenLite.from(line7, 0.5, {alpha: 0, x: 0, delay: delay + 1.5, ease: WIRE_EASE} );
			
			TweenLite.from(ctaBtn, 0.5, { alpha: 0, x: "-20", delay: delay + 3.5, onComplete: traceTimestamp } );
		}
		
		protected function showLoopReceptor():void
		{
			loopReceptor.play();
		}
		
		protected function highlightLines(lines:Array=null):void
		{	
			var glowOnFilterProps:Object = { color:0xFFFFFF, alpha:1, blurX:5, blurY:5 };
			var glowOffFilterProps:Object = { color:0xFFFFFF, alpha:0, blurX:5, blurY:5 };
			
			TweenLite.to(loopReceptor, 0.2, {alpha: RECEPTOR_HIGHLIGHT_ALPHA, glowFilter: glowOnFilterProps});
			TweenLite.to(loopReceptor, 0.2, { alpha: RECEPTOR_START_ALPHA, delay: 0.2, glowFilter: glowOffFilterProps} );
			
			if (lines) {
				var numLines:int = lines.length;
				var i:int;
				for (i = 0; i < numLines; i++) {
					var wire:MovieClip =  this["line" + lines[i]].wire;
					TweenLite.to(wire, 0.2, {alpha: RECEPTOR_HIGHLIGHT_ALPHA, glowFilter: glowOnFilterProps});
					TweenLite.to(wire, 0.2, { alpha: RECEPTOR_START_ALPHA, delay: 0.2, glowFilter: glowOffFilterProps} );
				}
			}
		}
		
		protected function traceTimestamp():void
		{
			var time:Number = getTimer() / 1000;
			trace(">> Timestamp: " + time );
		}
		
		// --------------------------------------------------------------------
		//	Event Handlers
		// --------------------------------------------------------------------
		
		private function clickTagBtn_clickHandler(event:MouseEvent):void 
		{
			// handle click tag for this banner
			var clickTag:String = "";
			
			if(root.loaderInfo.parameters.clicktag != null) {
				clickTag = root.loaderInfo.parameters.clicktag;
			} else if(root.loaderInfo.parameters.clickTag != null) {
				clickTag = root.loaderInfo.parameters.clickTag;
			} else if(root.loaderInfo.parameters.clickTAG != null) {
				clickTag = root.loaderInfo.parameters.clickTAG;
			}
			
			if(clickTag != "") {
				navigateToURL(new URLRequest(clickTag), "_blank");
			} else {
				trace("click tag");
			}
		}
		
		private function clickTagBtn_rollOverHandler(event:MouseEvent):void 
		{
			TweenLite.to(ctaBtn, 0.4, { tint: 0x2B2F12 } );
			TweenLite.to(ctaBtn.arrow, 0.4, { x: 70 } );
			TweenLite.to(ctaBtn.arrow, 0.4, { x: 65, delay: 0.4 } );
		}
		
		private function clickTagBtn_rollOutHandler(event:MouseEvent):void 
		{
			TweenLite.to(ctaBtn, 0.4, { tint: 0x595C43 } );
		}
	}
	
}